@@ -2,8 +2,8 @@ import os
 
 import yaml
 from termcolor2 import colored
-from TableReader import read_raw_sql_hub as r_hub
-from TableReader import read_raw_sql_sat as r_sat
+from dwhutils.TableReader import read_raw_sql_hub as r_hub
+from dwhutils.TableReader import read_raw_sql_sat as r_sat
 from db_connection import connect_to_db
 
 
